@@ -5,7 +5,9 @@ import appdirs
 
 name = "pydatasci"
 
-app_dir = appdirs.user_data_dir()
+app_dir_free = appdirs.user_data_dir()
+# need to make sure there's a trailing slash
+app_dir = os.path.join(app_dir_free, '')
 default_config_path = app_dir + "pydatasci_config.json"
 default_db_path = app_dir + "pydatasci_db.sqlite3"
 
@@ -13,7 +15,7 @@ default_db_path = app_dir + "pydatasci_db.sqlite3"
 def check_exists_folder():
 	app_dir_exists = os.path.exists(app_dir)
 	if app_dir_exists:
-		print("\n=> Success - the following file path exists on your system:\n" + app_dir + "\n")
+		print("\n=> Success - the following file path already exists on your system:\n" + app_dir + "\n")
 	else:
 		print("\n=> Error - the following file path does not exist on your system:\n" + app_dir + "\n")
 		print("\n=> Fix - you can attempt to fix this by running `pds.create_folder()`.\n")
@@ -29,11 +31,11 @@ def create_folder():
 		# ToDo - windows support.
 		try:
 			if os.name == 'nt':
-				# Windows: remember backslashes \
+				# Windows: backslashes \ and double backslashes \\
 				command = 'mkdir ' + app_dir
 				os.system(command)
 			else:
-				# posix
+				# posix (mac and linux)
 				command = 'mkdir -p "' + app_dir + '"'
 				os.system(command)
 		except:
@@ -41,10 +43,12 @@ def create_folder():
 			print("===================================\n")
 			raise
 		print("\n=> Success - created folder at file path:\n" + app_dir + "\n")
+		print("\n=> Fix - now try running `pds.create_config()` again.\n")
 
 
 def check_permissions_folder():
-	if check_exists_folder():
+	app_dir_exists = check_exists_folder()
+	if app_dir_exists:
 		# https://www.geeksforgeeks.org/python-os-access-method/
 		readable = os.access(app_dir, os.R_OK)
 		writeable = os.access(app_dir, os.W_OK)
@@ -64,8 +68,6 @@ def check_permissions_folder():
 		return False
 
 
-
-
 def grant_permissions_folder():
 	try:
 		if os.name == 'nt':
@@ -102,19 +104,20 @@ def get_config():
 def create_config():
 	config_exists = os.path.exists(default_config_path)
 	if not config_exists:
-			pds_config = {
-				"config_path": default_config_path,
-				"db_path": default_db_path,
-			}
-			
-			try:
-				with open(default_config_path, 'w') as pds_config_file:
-					json.dump(pds_config, pds_config_file)
-			except:
-				print("\n=> Error - failed to create config file at path:\n" + default_config_path)
-				print("===================================\n")
-				raise
-			print("\n=> Success - created config file for settings at path:\n" + default_config_path + "\n")
+		pds_config = {
+			"config_path": default_config_path,
+			"db_path": default_db_path,
+		}
+		
+		try:
+			with open(default_config_path, 'w') as pds_config_file:
+				json.dump(pds_config, pds_config_file)
+		except:
+			print("\n=> Error - failed to create config file at path:\n" + default_config_path)
+			print("\n=> Fix - you can attempt to fix this by running `pds.check_permissions_folder()`.\n")
+			print("===================================\n")
+			raise
+		print("\n=> Success - created config file for settings at path:\n" + default_config_path + "\n")
 	else:
 		print("\n=> Warning - skipping as config file already exists at path: " + default_config_path + "\n")
 
@@ -155,5 +158,5 @@ def update_config(kv:dict):
 			raise
 		print("\n=> Success - updated configuration settings:\n" + str(pds_config) + "\n")
 
-
+# This runs at startup and triggers the welcome message/ instruction if it is not configured.
 pds_config = get_config()
